@@ -61,7 +61,7 @@ typedef struct _GAppLaunchContextPrivate GAppLaunchContextPrivate;
  * @get_id: Gets a string identifier for a #GAppInfo.
  * @get_name: Gets the name of the application for a #GAppInfo.
  * @get_description: Gets a short description for the application described by the #GAppInfo.
- * @get_executable: Gets the execuable name for the #GAppInfo.
+ * @get_executable: Gets the executable name for the #GAppInfo.
  * @get_icon: Gets the #GIcon for the #GAppInfo.
  * @launch: Launches an application specified by the #GAppInfo.
  * @supports_uris: Indicates whether the application specified supports launching URIs.
@@ -71,12 +71,14 @@ typedef struct _GAppLaunchContextPrivate GAppLaunchContextPrivate;
  * <ulink url="http://standards.freedesktop.org/startup-notification-spec/startup-notification-latest.txt">
  * <citetitle>FreeDesktop.Org Startup Notification Specification</citetitle></ulink>.
  * @set_as_default_for_type: Sets an application as default for a given content type.
- * @set_as_default_for_extension: Sets an application as default for a given file extention.
+ * @set_as_default_for_extension: Sets an application as default for a given file extension.
  * @add_supports_type: Adds to the #GAppInfo information about supported file types.
  * @can_remove_supports_type: Checks for support for removing supported file types from a #GAppInfo.
  * @remove_supports_type: Removes a supported application type from a #GAppInfo.
  * @can_delete: Checks if a #GAppInfo can be deleted. Since 2.20
  * @do_delete: Deletes a #GAppInfo. Since 2.20
+ * @get_commandline: Gets the commandline for the #GAppInfo. Since 2.20
+ * @get_display_name: Gets the display name for the #GAppInfo. Since 2.24
  *
  * Application Information interface, for operating system portability.
  */
@@ -125,6 +127,7 @@ struct _GAppInfoIface
   gboolean     (* can_delete)                   (GAppInfo           *appinfo);
   gboolean     (* do_delete)                    (GAppInfo           *appinfo);
   const char * (* get_commandline)              (GAppInfo           *appinfo);
+  const char * (* get_display_name)             (GAppInfo           *appinfo);
 };
 
 GType       g_app_info_get_type                     (void) G_GNUC_CONST;
@@ -137,6 +140,7 @@ gboolean    g_app_info_equal                        (GAppInfo             *appin
 						     GAppInfo             *appinfo2);
 const char *g_app_info_get_id                       (GAppInfo             *appinfo);
 const char *g_app_info_get_name                     (GAppInfo             *appinfo);
+const char *g_app_info_get_display_name             (GAppInfo             *appinfo);
 const char *g_app_info_get_description              (GAppInfo             *appinfo);
 const char *g_app_info_get_executable               (GAppInfo             *appinfo);
 const char *g_app_info_get_commandline              (GAppInfo             *appinfo);
