@@ -39,6 +39,8 @@
 #include <direct.h>
 #include <io.h>
 #include <sys/utime.h>
+#else
+#include <utime.h>
 #endif
 
 #include "gstdio.h"
@@ -49,6 +51,10 @@
 #error Please port this to your operating system
 #endif
 
+#if defined (_MSC_VER) && !defined(_WIN64)
+#undef _wstat
+#define _wstat _wstat32
+#endif
 
 /**
  * g_access:
@@ -432,6 +438,20 @@ g_chdir (const gchar *path)
  * not look at the ACL at all. Thus on Windows the protection bits in
  * the st_mode field are a fabrication of little use.
  * 
+ * On Windows the Microsoft C libraries have several variants of the
+ * <structname>stat</structname> struct and stat() function with names
+ * like "_stat", "_stat32", "_stat32i64" and "_stat64i32". The one
+ * used here is for 32-bit code the one with 32-bit size and time
+ * fields, specifically called "_stat32".
+ *
+ * In Microsoft's compiler, by default "struct stat" means one with
+ * 64-bit time fields while in MinGW "struct stat" is the legacy one
+ * with 32-bit fields. To hopefully clear up this messs, the gstdio.h
+ * header defines a type GStatBuf which is the appropriate struct type
+ * depending on the platform and/or compiler being used. On POSIX it
+ * is just "struct stat", but note that even on POSIX platforms,
+ * "stat" might be a macro.
+ *
  * See your C library manual for more details about stat().
  *
  * Returns: 0 if the information was successfully retrieved, -1 if an error 
@@ -441,7 +461,7 @@ g_chdir (const gchar *path)
  */
 int
 g_stat (const gchar *filename,
-	struct stat *buf)
+	GStatBuf    *buf)
 {
 #ifdef G_OS_WIN32
   wchar_t *wfilename = g_utf8_to_utf16 (filename, -1, NULL, NULL, NULL);
@@ -462,7 +482,7 @@ g_stat (const gchar *filename,
       (!g_path_is_absolute (filename) || len > g_path_skip_root (filename) - filename))
     wfilename[len] = '\0';
 
-  retval = _wstat (wfilename, (struct _stat *) buf);
+  retval = _wstat (wfilename, buf);
   save_errno = errno;
 
   g_free (wfilename);
@@ -495,7 +515,7 @@ g_stat (const gchar *filename,
  */
 int
 g_lstat (const gchar *filename,
-	 struct stat *buf)
+	 GStatBuf    *buf)
 {
 #ifdef HAVE_LSTAT
   /* This can't be Win32, so don't do the widechar dance. */
